pub enum Border {
Empty,
Surround(BorderStyle),
Border(BorderStyle),
Vertical(BorderStyle),
VerBorder(BorderStyle),
Horizontal(BorderStyle),
HorBorder(BorderStyle),
}Expand description
Where to apply a BorderStyle around widgets
This type serves to determine whether frames will be applied only between widgets, around the whole application, or not at all:
Empty: Do not frame at all.Surround: Border on all sides.Border: Border only around files.Vertical: LikeSurround, but only on vertical lines.VerBorder: LikeBorder, but only on vertical lines.Horizontal: LikeSurround, but only on horizontal lines.HorBorder: LikeBorder, but only on horizontal lines.
Variants
Empty
No frame
Surround(BorderStyle)
Border the window’s edges and borders between widgets
Border(BorderStyle)
Border borders between widgets
Vertical(BorderStyle)
Border vertical window edges and borders between widgets
VerBorder(BorderStyle)
Border vertical borders between widgets
Horizontal(BorderStyle)
Border horizontal window edges and borders between widgets
HorBorder(BorderStyle)
Border horizontal borders between widgets