pub struct VertRule {
pub sep_char: SepChar,
/* private fields */
}Expand description
A vertical line on screen, useful, for example, for the separation
of a Buffer and LineNumbers.
By default, this VertRule will show the '│' character on the
whole line, using the "default.VertRule" form. However, you can
change that with the VertRule::sep_char field.
This field, of type SepChar, can have up to 3 distinct
characters, in order to differentiate between the main line’s
separator and even the separators above and below the main line.
If the main character is not the same as the other two characters,
then the line will be printed with the "rule.upper" and
"rule.lower" forms for the characters above and below.
Fields
sep_char: SepCharImplementations
Sourceimpl VertRule
impl VertRule
Sourcepub fn builder() -> VertRuleBuilder
pub fn builder() -> VertRuleBuilder
Returns a VertRuleBuilder, letting you push your own
VertRules around